@@ -21,8 +21,8 @@ const PASSWORD_SERVICE_NAME = 'gdm-password';
 const FINGERPRINT_SERVICE_NAME = 'gdm-fingerprint';
 const SMARTCARD_SERVICE_NAME = 'gdm-smartcard';
 const OVIRT_SERVICE_NAME = 'gdm-ovirtcred';
-const FADE_ANIMATION_TIME = 0.16;
-const CLONE_FADE_ANIMATION_TIME = 0.25;
+var FADE_ANIMATION_TIME = 0.16;
+var CLONE_FADE_ANIMATION_TIME = 0.25;
 
 const LOGIN_SCREEN_SCHEMA = 'org.gnome.login-screen';
 const PASSWORD_AUTHENTICATION_KEY = 'enable-password-authentication';
@@ -36,9 +36,9 @@ const LOGO_KEY = 'logo';
 const DISABLE_USER_LIST_KEY = 'disable-user-list';
 
 // Give user 48ms to read each character of a PAM message
-const USER_READ_TIME = 48
+var USER_READ_TIME = 48
 
-const MessageType = {
+var MessageType = {
     NONE: 0,
     ERROR: 1,
     INFO: 2,
@@ -119,7 +119,7 @@ function cloneAndFadeOutActor(actor) {
     return hold;
 }
 
-const ShellUserVerifier = new Lang.Class({
+var ShellUserVerifier = new Lang.Class({
     Name: 'ShellUserVerifier',
 
     _init: function(client, params) {
@@ -128,6 +128,9 @@ const ShellUserVerifier = new Lang.Class({
 
         this._client = client;
 
+        this._defaultService = null;
+        this._preemptingService = null;
+
         this._settings = new Gio.Settings({ schema_id: LOGIN_SCREEN_SCHEMA });
         this._settings.connect('changed',
                                Lang.bind(this, this._updateDefaultService));
@@ -138,8 +141,9 @@ const ShellUserVerifier = new Lang.Class({
 
         // We check for smartcards right away, since an inserted smartcard
         // at startup should result in immediately initiating authentication.
-        // This is different than fingeprint readers, where we only check them
+        // This is different than fingerprint readers, where we only check them
         // after a user has been picked.
+        this.smartcardDetected = false;
         this._checkForSmartcard();
 
         this._smartcardInsertedId = this._smartcardManager.connect('smartcard-inserted',
@@ -540,7 +544,8 @@ const ShellUserVerifier = new Lang.Class({
                 let signalId = this.connect('no-more-messages',
                                             Lang.bind(this, function() {
                                                 this.disconnect(signalId);
-                                                this._retry();
+                                                if (this._cancellable && !this._cancellable.is_cancelled())
+                                                    this._retry();
                                             }));
             }
         } else {
