@@ -18,12 +18,12 @@ const Main = imports.ui.main;
 const Params = imports.misc.params;
 const Tweener = imports.ui.tweener;
 
-const STARTUP_ANIMATION_TIME = 0.5;
-const KEYBOARD_ANIMATION_TIME = 0.15;
-const BACKGROUND_FADE_ANIMATION_TIME = 1.0;
+var STARTUP_ANIMATION_TIME = 0.5;
+var KEYBOARD_ANIMATION_TIME = 0.15;
+var BACKGROUND_FADE_ANIMATION_TIME = 1.0;
 
-const HOT_CORNER_PRESSURE_THRESHOLD = 100; // pixels
-const HOT_CORNER_PRESSURE_TIMEOUT = 1000; // ms
+var HOT_CORNER_PRESSURE_THRESHOLD = 100; // pixels
+var HOT_CORNER_PRESSURE_TIMEOUT = 1000; // ms
 
 function isPopupMetaWindow(actor) {
     switch(actor.meta_window.get_window_type()) {
@@ -36,7 +36,7 @@ function isPopupMetaWindow(actor) {
     }
 }
 
-const MonitorConstraint = new Lang.Class({
+var MonitorConstraint = new Lang.Class({
     Name: 'MonitorConstraint',
     Extends: Clutter.Constraint,
     Properties: {'primary': GObject.ParamSpec.boolean('primary', 
@@ -147,7 +147,7 @@ const MonitorConstraint = new Lang.Class({
     }
 });
 
-const Monitor = new Lang.Class({
+var Monitor = new Lang.Class({
     Name: 'Monitor',
 
     _init: function(index, geometry) {
@@ -169,7 +169,7 @@ const defaultParams = {
     affectsInputRegion: true
 };
 
-const LayoutManager = new Lang.Class({
+var LayoutManager = new Lang.Class({
     Name: 'LayoutManager',
 
     _init: function () {
@@ -769,8 +769,7 @@ const LayoutManager = new Lang.Class({
     // @actor: a descendant of the chrome to begin tracking
     // @params: parameters describing how to track @actor
     //
-    // Tells the chrome to track @actor, which must be a descendant
-    // of an actor added via addChrome(). This can be used to extend the
+    // Tells the chrome to track @actor. This can be used to extend the
     // struts or input region to cover specific children.
     //
     // @params can have any of the same values as in addChrome(),
@@ -783,10 +782,9 @@ const LayoutManager = new Lang.Class({
             ancestor = ancestor.get_parent();
             index = this._findActor(ancestor);
         }
-        if (!ancestor)
-            throw new Error('actor is not a descendent of a chrome actor');
 
-        let ancestorData = this._trackedActors[index];
+        let ancestorData = ancestor ? this._trackedActors[index]
+                                    : defaultParams;
         if (!params)
             params = {};
         // We can't use Params.parse here because we want to drop
@@ -1047,7 +1045,7 @@ Signals.addSignalMethods(LayoutManager.prototype);
 //
 // This class manages a "hot corner" that can toggle switching to
 // overview.
-const HotCorner = new Lang.Class({
+var HotCorner = new Lang.Class({
     Name: 'HotCorner',
 
     _init : function(layoutManager, monitor, x, y) {
@@ -1241,7 +1239,7 @@ const HotCorner = new Lang.Class({
     }
 });
 
-const PressureBarrier = new Lang.Class({
+var PressureBarrier = new Lang.Class({
     Name: 'PressureBarrier',
 
     _init: function(threshold, timeout, actionMode) {
