@@ -50,36 +50,36 @@ const A11Y_SCHEMA = 'org.gnome.desktop.a11y.keyboard';
 const STICKY_KEYS_ENABLE = 'stickykeys-enable';
 const GNOMESHELL_STARTED_MESSAGE_ID = 'f3ea493c22934e26811cd62abe8e203a';
 
-let componentManager = null;
-let panel = null;
-let overview = null;
-let runDialog = null;
-let lookingGlass = null;
-let wm = null;
-let legacyTray = null;
-let messageTray = null;
-let screenShield = null;
-let notificationDaemon = null;
-let windowAttentionHandler = null;
-let ctrlAltTabManager = null;
-let padOsdService = null;
-let osdWindowManager = null;
-let osdMonitorLabeler = null;
-let sessionMode = null;
-let shellAccessDialogDBusService = null;
-let shellAudioSelectionDBusService = null;
-let shellDBusService = null;
-let shellMountOpDBusService = null;
-let screenSaverDBus = null;
-let screencastService = null;
-let modalCount = 0;
-let actionMode = Shell.ActionMode.NONE;
-let modalActorFocusStack = [];
-let uiGroup = null;
-let magnifier = null;
-let xdndHandler = null;
-let keyboard = null;
-let layoutManager = null;
+var componentManager = null;
+var panel = null;
+var overview = null;
+var runDialog = null;
+var lookingGlass = null;
+var wm = null;
+var legacyTray = null;
+var messageTray = null;
+var screenShield = null;
+var notificationDaemon = null;
+var windowAttentionHandler = null;
+var ctrlAltTabManager = null;
+var padOsdService = null;
+var osdWindowManager = null;
+var osdMonitorLabeler = null;
+var sessionMode = null;
+var shellAccessDialogDBusService = null;
+var shellAudioSelectionDBusService = null;
+var shellDBusService = null;
+var shellMountOpDBusService = null;
+var screenSaverDBus = null;
+var screencastService = null;
+var modalCount = 0;
+var actionMode = Shell.ActionMode.NONE;
+var modalActorFocusStack = [];
+var uiGroup = null;
+var magnifier = null;
+var xdndHandler = null;
+var keyboard = null;
+var layoutManager = null;
 let _startDate;
 let _defaultCssStylesheet = null;
 let _cssStylesheet = null;
@@ -552,7 +552,7 @@ function activateWindow(window, time, workspaceNum) {
 
 // TODO - replace this timeout with some system to guess when the user might
 // be e.g. just reading the screen and not likely to interact.
-const DEFERRED_TIMEOUT_SECONDS = 20;
+var DEFERRED_TIMEOUT_SECONDS = 20;
 var _deferredWorkData = {};
 // Work scheduled for some point in the future
 var _deferredWorkQueue = [];
@@ -669,7 +669,7 @@ function queueDeferredWork(workId) {
     }
 }
 
-const RestartMessage = new Lang.Class({
+var RestartMessage = new Lang.Class({
     Name: 'RestartMessage',
     Extends: ModalDialog.ModalDialog,
 
