@@ -14,7 +14,7 @@ const Tweener = imports.ui.tweener;
 const ViewSelector = imports.ui.viewSelector;
 const WorkspaceThumbnail = imports.ui.workspaceThumbnail;
 
-const SIDE_CONTROLS_ANIMATION_TIME = 0.16;
+var SIDE_CONTROLS_ANIMATION_TIME = 0.16;
 
 function getRtlSlideDirection(direction, actor) {
     let rtl = (actor.text_direction == Clutter.TextDirection.RTL);
@@ -25,12 +25,12 @@ function getRtlSlideDirection(direction, actor) {
     return direction;
 };
 
-const SlideDirection = {
+var SlideDirection = {
     LEFT: 0,
     RIGHT: 1
 };
 
-const SlideLayout = new Lang.Class({
+var SlideLayout = new Lang.Class({
     Name: 'SlideLayout',
     Extends: Clutter.FixedLayout,
 
@@ -104,7 +104,7 @@ const SlideLayout = new Lang.Class({
     },
 });
 
-const SlidingControl = new Lang.Class({
+var SlidingControl = new Lang.Class({
     Name: 'SlidingControl',
 
     _init: function(params) {
@@ -238,7 +238,7 @@ const SlidingControl = new Lang.Class({
     }
 });
 
-const ThumbnailsSlider = new Lang.Class({
+var ThumbnailsSlider = new Lang.Class({
     Name: 'ThumbnailsSlider',
     Extends: SlidingControl,
 
@@ -314,7 +314,7 @@ const ThumbnailsSlider = new Lang.Class({
     }
 });
 
-const DashSlider = new Lang.Class({
+var DashSlider = new Lang.Class({
     Name: 'DashSlider',
     Extends: SlidingControl,
 
@@ -353,7 +353,7 @@ const DashSlider = new Lang.Class({
     }
 });
 
-const DashSpacer = new Lang.Class({
+var DashSpacer = new Lang.Class({
     Name: 'DashSpacer',
     Extends: St.Widget,
 
@@ -391,7 +391,7 @@ const DashSpacer = new Lang.Class({
     }
 });
 
-const ControlsLayout = new Lang.Class({
+var ControlsLayout = new Lang.Class({
     Name: 'ControlsLayout',
     Extends: Clutter.BinLayout,
     Signals: { 'allocation-changed': { flags: GObject.SignalFlags.RUN_LAST } },
@@ -402,7 +402,7 @@ const ControlsLayout = new Lang.Class({
     }
 });
 
-const ControlsManager = new Lang.Class({
+var ControlsManager = new Lang.Class({
     Name: 'ControlsManager',
 
     _init: function(searchEntry) {
