@@ -181,7 +181,7 @@ function loadRemoteSearchProviders(searchSettings, callback) {
     callback(loadedProviders);
 }
 
-const RemoteSearchProvider = new Lang.Class({
+var RemoteSearchProvider = new Lang.Class({
     Name: 'RemoteSearchProvider',
 
     _init: function(appInfo, dbusName, dbusPath, proxyInfo) {
@@ -200,6 +200,7 @@ const RemoteSearchProvider = new Lang.Class({
         this.appInfo = appInfo;
         this.id = appInfo.get_id();
         this.isRemoteProvider = true;
+        this.canLaunchSearch = false;
     },
 
     createIcon: function(size, meta) {
@@ -298,11 +299,11 @@ const RemoteSearchProvider = new Lang.Class({
         // the provider is not compatible with the new version of the interface, launch
         // the app itself but warn so we can catch the error in logs
         log('Search provider ' + this.appInfo.get_id() + ' does not implement LaunchSearch');
-        this.appInfo.launch([], global.create_app_launch_context(0, -1), false);
+        this.appInfo.launch([], global.create_app_launch_context(0, -1));
     }
 });
 
-const RemoteSearchProvider2 = new Lang.Class({
+var RemoteSearchProvider2 = new Lang.Class({
     Name: 'RemoteSearchProvider2',
     Extends: RemoteSearchProvider,
 
