@@ -12,6 +12,7 @@ const Shell = imports.gi.Shell;
 const Signals = imports.signals;
 
 const AltTab = imports.ui.altTab;
+const Dialog = imports.ui.dialog;
 const WorkspaceSwitcherPopup = imports.ui.workspaceSwitcherPopup;
 const Main = imports.ui.main;
 const ModalDialog = imports.ui.modalDialog;
@@ -19,20 +20,21 @@ const Tweener = imports.ui.tweener;
 const WindowMenu = imports.ui.windowMenu;
 const PadOsd = imports.ui.padOsd;
 const EdgeDragAction = imports.ui.edgeDragAction;
+const CloseDialog = imports.ui.closeDialog;
 
 const SHELL_KEYBINDINGS_SCHEMA = 'org.gnome.shell.keybindings';
-const MINIMIZE_WINDOW_ANIMATION_TIME = 0.2;
-const SHOW_WINDOW_ANIMATION_TIME = 0.15;
-const DIALOG_SHOW_WINDOW_ANIMATION_TIME = 0.1;
-const DESTROY_WINDOW_ANIMATION_TIME = 0.15;
-const DIALOG_DESTROY_WINDOW_ANIMATION_TIME = 0.1;
-const WINDOW_ANIMATION_TIME = 0.25;
-const DIM_BRIGHTNESS = -0.3;
-const DIM_TIME = 0.500;
-const UNDIM_TIME = 0.250;
+var MINIMIZE_WINDOW_ANIMATION_TIME = 0.2;
+var SHOW_WINDOW_ANIMATION_TIME = 0.15;
+var DIALOG_SHOW_WINDOW_ANIMATION_TIME = 0.1;
+var DESTROY_WINDOW_ANIMATION_TIME = 0.15;
+var DIALOG_DESTROY_WINDOW_ANIMATION_TIME = 0.1;
+var WINDOW_ANIMATION_TIME = 0.25;
+var DIM_BRIGHTNESS = -0.3;
+var DIM_TIME = 0.500;
+var UNDIM_TIME = 0.250;
 
-const DISPLAY_REVERT_TIMEOUT = 20; // in seconds - keep in sync with mutter
-const ONE_SECOND = 1000; // in ms
+var DISPLAY_REVERT_TIMEOUT = 20; // in seconds - keep in sync with mutter
+var ONE_SECOND = 1000; // in ms
 
 const GSD_WACOM_BUS_NAME = 'org.gnome.SettingsDaemon.Wacom';
 const GSD_WACOM_OBJECT_PATH = '/org/gnome/SettingsDaemon/Wacom';
@@ -53,7 +55,7 @@ const GsdWacomIface = '<node name="/org/gnome/SettingsDaemon/Wacom"> \
 
 const GsdWacomProxy = Gio.DBusProxy.makeProxyWrapper(GsdWacomIface);
 
-const DisplayChangeDialog = new Lang.Class({
+var DisplayChangeDialog = new Lang.Class({
     Name: 'DisplayChangeDialog',
     Extends: ModalDialog.ModalDialog,
 
@@ -62,41 +64,19 @@ const DisplayChangeDialog = new Lang.Class({
 
         this._wm = wm;
 
-        let mainContentBox = new St.BoxLayout({ style_class: 'prompt-dialog-main-layout',
-                                                vertical: false });
-        this.contentLayout.add(mainContentBox,
+        this._countDown = DISPLAY_REVERT_TIMEOUT;
+
+        let iconName = 'preferences-desktop-display-symbolic';
+        let icon = new Gio.ThemedIcon({ name: iconName });
+        let title = _("Do you want to keep these display settings?");
+        let body = this._formatCountDown();
+
+        this._content = new Dialog.MessageDialogContent({ icon, title, body });
+
+        this.contentLayout.add(this._content,
                                { x_fill: true,
                                  y_fill: true });
 
-        let icon = new St.Icon({ icon_name: 'preferences-desktop-display-symbolic' });
-        mainContentBox.add(icon,
-                           { x_fill:  true,
-                             y_fill:  false,
-                             x_align: St.Align.END,
-                             y_align: St.Align.START });
-
-        let messageBox = new St.BoxLayout({ style_class: 'prompt-dialog-message-layout',
-                                            vertical: true });
-        mainContentBox.add(messageBox,
-                           { expand: true, y_align: St.Align.START });
-
-        let subjectLabel = new St.Label({ style_class: 'prompt-dialog-headline',
-                                            text: _("Do you want to keep these display settings?") });
-        messageBox.add(subjectLabel,
-                       { y_fill:  false,
-                         y_align: St.Align.START });
-
-        this._countDown = DISPLAY_REVERT_TIMEOUT;
-        let message = this._formatCountDown();
-        this._descriptionLabel = new St.Label({ style_class: 'prompt-dialog-description',
-                                                text: this._formatCountDown() });
-        this._descriptionLabel.clutter_text.ellipsize = Pango.EllipsizeMode.NONE;
-        this._descriptionLabel.clutter_text.line_wrap = true;
-
-        messageBox.add(this._descriptionLabel,
-                       { y_fill:  true,
-                         y_align: St.Align.START });
-
         /* Translators: this and the following message should be limited in lenght,
            to avoid ellipsizing the labels.
         */
@@ -136,7 +116,7 @@ const DisplayChangeDialog = new Lang.Class({
             return GLib.SOURCE_REMOVE;
         }
 
-        this._descriptionLabel.text = this._formatCountDown();
+        this._content.body = this._formatCountDown();
         return GLib.SOURCE_CONTINUE;
     },
 
@@ -151,7 +131,7 @@ const DisplayChangeDialog = new Lang.Class({
     },
 });
 
-const WindowDimmer = new Lang.Class({
+var WindowDimmer = new Lang.Class({
     Name: 'WindowDimmer',
 
     _init: function(actor) {
@@ -203,9 +183,9 @@ function getWindowDimmer(actor) {
  * the main window of an application, and give the app a grace period
  * where it can map another window before we remove the workspace.
  */
-const LAST_WINDOW_GRACE_TIME = 1000;
+var LAST_WINDOW_GRACE_TIME = 1000;
 
-const WorkspaceTracker = new Lang.Class({
+var WorkspaceTracker = new Lang.Class({
     Name: 'WorkspaceTracker',
 
     _init: function(wm) {
@@ -409,7 +389,7 @@ const WorkspaceTracker = new Lang.Class({
     }
 });
 
-const TilePreview = new Lang.Class({
+var TilePreview = new Lang.Class({
     Name: 'TilePreview',
 
     _init: function() {
@@ -496,7 +476,7 @@ const TilePreview = new Lang.Class({
     }
 });
 
-const TouchpadWorkspaceSwitchAction = new Lang.Class({
+var TouchpadWorkspaceSwitchAction = new Lang.Class({
     Name: 'TouchpadWorkspaceSwitchAction',
 
     _init: function(actor) {
@@ -552,7 +532,7 @@ const TouchpadWorkspaceSwitchAction = new Lang.Class({
 });
 Signals.addSignalMethods(TouchpadWorkspaceSwitchAction.prototype);
 
-const WorkspaceSwitchAction = new Lang.Class({
+var WorkspaceSwitchAction = new Lang.Class({
     Name: 'WorkspaceSwitchAction',
     Extends: Clutter.SwipeAction,
     Signals: { 'activated': { param_types: [Meta.MotionDirection.$gtype] } },
@@ -594,7 +574,7 @@ const WorkspaceSwitchAction = new Lang.Class({
     }
 });
 
-const AppSwitchAction = new Lang.Class({
+var AppSwitchAction = new Lang.Class({
     Name: 'AppSwitchAction',
     Extends: Clutter.GestureAction,
     Signals: { 'activated': {} },
@@ -660,7 +640,7 @@ const AppSwitchAction = new Lang.Class({
     }
 });
 
-const ResizePopup = new Lang.Class({
+var ResizePopup = new Lang.Class({
     Name: 'ResizePopup',
 
     _init: function() {
@@ -689,7 +669,7 @@ const ResizePopup = new Lang.Class({
     },
 });
 
-const WindowManager = new Lang.Class({
+var WindowManager = new Lang.Class({
     Name: 'WindowManager',
 
     _init : function() {
@@ -731,6 +711,7 @@ const WindowManager = new Lang.Class({
         this._shellwm.connect('destroy', Lang.bind(this, this._destroyWindow));
         this._shellwm.connect('filter-keybinding', Lang.bind(this, this._filterKeybinding));
         this._shellwm.connect('confirm-display-change', Lang.bind(this, this._confirmDisplayChange));
+        this._shellwm.connect('create-close-dialog', Lang.bind(this, this._createCloseDialog));
         global.screen.connect('restacked', Lang.bind(this, this._syncStacking));
 
         this._workspaceSwitcherPopup = null;
@@ -1604,7 +1585,7 @@ const WindowManager = new Lang.Class({
             return;
         }
 
-        switch (actor._windowType) {
+        switch (actor.meta_window.window_type) {
         case Meta.WindowType.NORMAL:
             actor.set_pivot_point(0.5, 0.5);
             this._destroying.push(actor);
@@ -1992,6 +1973,10 @@ const WindowManager = new Lang.Class({
         dialog.open();
     },
 
+    _createCloseDialog: function (shellwm, window) {
+        return new CloseDialog.CloseDialog(window);
+    },
+
     _showResizePopup: function(display, show, rect, displayW, displayH) {
         if (show) {
             if (!this._resizePopup)
