@@ -18,29 +18,29 @@ const Overview = imports.ui.overview;
 const Tweener = imports.ui.tweener;
 const WindowManager = imports.ui.windowManager;
 
-const WINDOW_DND_SIZE = 256;
+var WINDOW_DND_SIZE = 256;
 
-const WINDOW_CLONE_MAXIMUM_SCALE = 0.7;
+var WINDOW_CLONE_MAXIMUM_SCALE = 0.7;
 
-const CLOSE_BUTTON_FADE_TIME = 0.1;
+var CLOSE_BUTTON_FADE_TIME = 0.1;
 
-const DRAGGING_WINDOW_OPACITY = 100;
+var DRAGGING_WINDOW_OPACITY = 100;
 
 // When calculating a layout, we calculate the scale of windows and the percent
 // of the available area the new layout uses. If the values for the new layout,
 // when weighted with the values as below, are worse than the previous layout's,
 // we stop looking for a new layout and use the previous layout.
 // Otherwise, we keep looking for a new layout.
-const LAYOUT_SCALE_WEIGHT = 1;
-const LAYOUT_SPACE_WEIGHT = 0.1;
+var LAYOUT_SCALE_WEIGHT = 1;
+var LAYOUT_SPACE_WEIGHT = 0.1;
 
-const WINDOW_ANIMATION_MAX_NUMBER_BLENDING = 3;
+var WINDOW_ANIMATION_MAX_NUMBER_BLENDING = 3;
 
 function _interpolate(start, end, step) {
     return start + (end - start) * step;
 }
 
-const WindowCloneLayout = new Lang.Class({
+var WindowCloneLayout = new Lang.Class({
     Name: 'WindowCloneLayout',
     Extends: Clutter.LayoutManager,
 
@@ -102,7 +102,7 @@ const WindowCloneLayout = new Lang.Class({
     }
 });
 
-const WindowClone = new Lang.Class({
+var WindowClone = new Lang.Class({
     Name: 'WindowClone',
 
     _init : function(realWindow, workspace) {
@@ -423,7 +423,7 @@ Signals.addSignalMethods(WindowClone.prototype);
  * @parentActor: The actor which will be the parent of all overlay items
  *               such as app icon and window caption
  */
-const WindowOverlay = new Lang.Class({
+var WindowOverlay = new Lang.Class({
     Name: 'WindowOverlay',
 
     _init : function(windowClone, parentActor) {
@@ -500,7 +500,7 @@ const WindowOverlay = new Lang.Class({
         this._hidden = false;
 
         this.title.show();
-        if (this._windowClone.actor.has_pointer)
+        if (this._windowClone.actor.has_pointer())
             this._animateVisible();
     },
 
@@ -699,8 +699,8 @@ const WindowOverlay = new Lang.Class({
     _idleToggleCloseButton: function() {
         this._idleToggleCloseId = 0;
 
-        if (!this._windowClone.actor.has_pointer &&
-            !this.closeButton.has_pointer)
+        if (!this._windowClone.actor.has_pointer() &&
+            !this.closeButton.has_pointer())
             this._animateInvisible();
 
         return GLib.SOURCE_REMOVE;
@@ -731,7 +731,7 @@ const WindowOverlay = new Lang.Class({
 });
 Signals.addSignalMethods(WindowOverlay.prototype);
 
-const WindowPositionFlags = {
+var WindowPositionFlags = {
     NONE: 0,
     INITIAL: 1 << 0,
     ANIMATE: 1 << 1
@@ -811,7 +811,7 @@ const WindowPositionFlags = {
 // each window's "cell" area to be the same, but we shrink the thumbnail
 // and center it horizontally, and align it to the bottom vertically.
 
-const LayoutStrategy = new Lang.Class({
+var LayoutStrategy = new Lang.Class({
     Name: 'LayoutStrategy',
     Abstract: true,
 
@@ -983,7 +983,7 @@ const LayoutStrategy = new Lang.Class({
     }
 });
 
-const UnalignedLayoutStrategy = new Lang.Class({
+var UnalignedLayoutStrategy = new Lang.Class({
     Name: 'UnalignedLayoutStrategy',
     Extends: LayoutStrategy,
 
@@ -1094,7 +1094,7 @@ function rectEqual(one, two) {
 /**
  * @metaWorkspace: a #Meta.Workspace, or null
  */
-const Workspace = new Lang.Class({
+var Workspace = new Lang.Class({
     Name: 'Workspace',
 
     _init : function(metaWorkspace, monitorIndex) {
@@ -1794,14 +1794,20 @@ const Workspace = new Lang.Class({
         global.screen.disconnect(this._windowEnteredMonitorId);
         global.screen.disconnect(this._windowLeftMonitorId);
 
-        if (this._repositionWindowsId > 0)
+        if (this._repositionWindowsId > 0) {
             Mainloop.source_remove(this._repositionWindowsId);
+            this._repositionWindowsId = 0;
+        }
 
-        if (this._positionWindowsId > 0)
+        if (this._positionWindowsId > 0) {
             Meta.later_remove(this._positionWindowsId);
+            this._positionWindowsId = 0;
+        }
 
-        if (this._actualGeometryLater > 0)
+        if (this._actualGeometryLater > 0) {
             Meta.later_remove(this._actualGeometryLater);
+            this._actualGeometryLater = 0;
+        }
 
         this._windows = [];
     },
