@@ -21,21 +21,21 @@ const WorkspacesView = imports.ui.workspacesView;
 // The maximum size of a thumbnail is 1/8 the width and height of the screen
 let MAX_THUMBNAIL_SCALE = 1/8.;
 
-const RESCALE_ANIMATION_TIME = 0.2;
-const SLIDE_ANIMATION_TIME = 0.2;
+var RESCALE_ANIMATION_TIME = 0.2;
+var SLIDE_ANIMATION_TIME = 0.2;
 
 // When we create workspaces by dragging, we add a "cut" into the top and
 // bottom of each workspace so that the user doesn't have to hit the
 // placeholder exactly.
-const WORKSPACE_CUT_SIZE = 10;
+var WORKSPACE_CUT_SIZE = 10;
 
-const WORKSPACE_KEEP_ALIVE_TIME = 100;
+var WORKSPACE_KEEP_ALIVE_TIME = 100;
 
 const OVERRIDE_SCHEMA = 'org.gnome.shell.overrides';
 
 /* A layout manager that requests size only for primary_actor, but then allocates
    all using a fixed layout */
-const PrimaryActorLayout = new Lang.Class({
+var PrimaryActorLayout = new Lang.Class({
     Name: 'PrimaryActorLayout',
     Extends: Clutter.FixedLayout,
 
@@ -54,7 +54,7 @@ const PrimaryActorLayout = new Lang.Class({
     },
 });
 
-const WindowClone = new Lang.Class({
+var WindowClone = new Lang.Class({
     Name: 'WindowClone',
 
     _init : function(realWindow) {
@@ -254,7 +254,7 @@ const ThumbnailState = {
 /**
  * @metaWorkspace: a #Meta.Workspace
  */
-const WorkspaceThumbnail = new Lang.Class({
+var WorkspaceThumbnail = new Lang.Class({
     Name: 'WorkspaceThumbnail',
 
     _init : function(metaWorkspace) {
@@ -612,7 +612,7 @@ const WorkspaceThumbnail = new Lang.Class({
 Signals.addSignalMethods(WorkspaceThumbnail.prototype);
 
 
-const ThumbnailsBox = new Lang.Class({
+var ThumbnailsBox = new Lang.Class({
     Name: 'ThumbnailsBox',
 
     _init: function() {
@@ -676,6 +676,12 @@ const ThumbnailsBox = new Lang.Class({
         this._settings = new Gio.Settings({ schema_id: OVERRIDE_SCHEMA });
         this._settings.connect('changed::dynamic-workspaces',
             Lang.bind(this, this._updateSwitcherVisibility));
+
+        Main.layoutManager.connect('monitors-changed', Lang.bind(this, function() {
+            this._destroyThumbnails();
+            if (Main.overview.visible)
+                this._createThumbnails();
+        }));
     },
 
     _updateSwitcherVisibility: function() {
